@@ -1,4 +1,4 @@
-static const AVFilter * const filter_list[] = {
+static const FFFilter * const filter_list[] = {
     &ff_af_aap,
     &ff_af_abench,
     &ff_af_acompressor,
@@ -162,6 +162,7 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_bilateral_cuda,
     &ff_vf_bitplanenoise,
     &ff_vf_blackdetect,
+    &ff_vf_blackdetect_vulkan,
     &ff_vf_blackframe,
     &ff_vf_blend,
     &ff_vf_blend_vulkan,
@@ -187,6 +188,7 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_colorchannelmixer,
     &ff_vf_colorcontrast,
     &ff_vf_colorcorrect,
+    &ff_vf_colordetect,
     &ff_vf_colorize,
     &ff_vf_colorkey,
     &ff_vf_colorkey_opencl,
@@ -296,6 +298,7 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_il,
     &ff_vf_inflate,
     &ff_vf_interlace,
+    &ff_vf_interlace_vulkan,
     &ff_vf_interleave,
     &ff_vf_kerndeint,
     &ff_vf_kirsch,
@@ -351,6 +354,7 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_overlay_cuda,
     &ff_vf_owdenoise,
     &ff_vf_pad,
+    &ff_vf_pad_cuda,
     &ff_vf_pad_opencl,
     &ff_vf_palettegen,
     &ff_vf_paletteuse,
@@ -361,7 +365,6 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_pixdesctest,
     &ff_vf_pixelize,
     &ff_vf_pixscope,
-    &ff_vf_pp,
     &ff_vf_pp7,
     &ff_vf_premultiply,
     &ff_vf_prewitt,
@@ -388,12 +391,15 @@ static const AVFilter * const filter_list[] = {
     &ff_vf_rotate,
     &ff_vf_sab,
     &ff_vf_scale,
+    &ff_vf_vpp_amf,
+    &ff_vf_sr_amf,
     &ff_vf_scale_cuda,
     &ff_vf_scale_qsv,
     &ff_vf_scale_vaapi,
     &ff_vf_scale_vulkan,
     &ff_vf_scale2ref,
     &ff_vf_scdet,
+    &ff_vf_scdet_vulkan,
     &ff_vf_scharr,
     &ff_vf_scroll,
     &ff_vf_segment,
